/*
* Copyright (c) 2005-2009 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
* which accompanies this distribution, and is available
* at the URL "http://www.eclipse.org/legal/epl-v10.html".
*
* Initial Contributors:
* Nokia Corporation - initial contribution.
*
* Contributors:
*
* Description: 
*
*/




#if (!defined __TESTADDMULTIPLECONTACTSSTEP_H__)
#define __TESTADDMULTIPLECONTACTSSTEP_H__
#include <test/testexecutestepbase.h>
class CTestAddMultipleContactsStep : public CTestStep
	{
public:
	CTestAddMultipleContactsStep();
	~CTestAddMultipleContactsStep();
	virtual TVerdict doTestStepPreambleL();
	virtual TVerdict doTestStepL();
	virtual TVerdict doTestStepPostambleL();


private:
	CActiveScheduler* iScheduler;

	void OpenExistingContactL(TPtrC aValue, TInt aStorageType,TUid aContFieldUid, TUid avCardMapUid);
	void DeleteExistContactL(TUid aContFieldUid, TUid avCardMap);
	void AddMultipleContactsL(TPtrC aValue, TInt aStorageType,TUid aContFieldUid, TUid avCardMapUid);
	static TInt iStorage[];
	static TUid iFieldUid[];
	static TUid iVcardUid[];
	};

_LIT(KTestAddMultipleContactsStep,"TestAddMultipleContactsStep");

#endif
